@@ -16,18 +16,18 @@ class Filter(BaseFilterModel):
             created_at: DatetimeField()
 
         class MyModelFilter(Filter):
-            id: int | None
-            id__in: str | None
-            count: int | None
-            count__lte: int | None
-            created_at__gt: datetime | None
-            name__ne: str | None
-            name__nin: list[str] | None
-            name__isnull: bool | None
+            id: Optional[int]
+            id__in: Optional[str]
+            count: Optional[int]
+            count__lte: Optional[int]
+            created_at__gt: Optional[datetime]
+            name__ne: Optional[str]
+            name__nin: Optional[list[str]]
+            name__isnull: Optional[bool]
         ```
     """
 
-    def sort(self, query: QuerySet):
+    def sort(self, query: QuerySet) -> QuerySet:
         if not self.ordering_values:
             return query
         return query.order_by(*self.ordering_values)
@@ -42,7 +42,7 @@ class Filter(BaseFilterModel):
             return [field.type_(v) for v in value.split(",")]
         return value
 
-    def filter(self, query: QuerySet):
+    def filter(self, query: QuerySet) -> QuerySet:
         for field_name, value in self.filtering_fields:
             field_value = getattr(self, field_name)
             if isinstance(field_value, Filter):
